/*  suxviewer
 *  Copyright (C) 1999, Watanabe Toshiki
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
*/

#include <string.h>
#include <gtk/gtk.h>
#include "option.h"
#include "config.h"

/* Widget as global variable */
GtkWidget *clist_curve;

void on_curve_add_clicked (GtkButton *button, GtkWidget *dialog)
{
  char *item[3];
  GtkWidget *cf;
  GtkWidget *cn;
  GtkWidget *cc;

  cf = (GtkWidget*) gtk_object_get_data (GTK_OBJECT (dialog),
					 "entry_cf");
  item[0] = strdup(gtk_entry_get_text(GTK_ENTRY(cf)));
  cn = (GtkWidget*) gtk_object_get_data (GTK_OBJECT (dialog),
					 "spinbutton_cn");
  item[1] = strdup(gtk_entry_get_text(&(GTK_SPIN_BUTTON(cn)->entry)));
  cc = (GtkWidget*) gtk_object_get_data (GTK_OBJECT (dialog),
					 "combo_cc");
  item[2] = strdup(gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(cc)->entry)));

  if(!*item[0] || !*item[1] || !*item[2] ) return;

  gtk_clist_append(GTK_CLIST(clist_curve), item); 

  curve.ncurve++;
  if (curve.ncurve == 1){
    strcpy (curve.curve, item[0]);
    strcpy (curve.npair, item[1]);
    strcpy (curve.curvecolor, item[2]);
  } else {
    strcat(curve.curve, ","); strcat(curve.curve, item[0]);
    strcat(curve.npair, ","); strcat(curve.npair, item[1]);
    strcat(curve.curvecolor, ","); strcat(curve.curvecolor, item[2]);
  }
  return;
}

void on_curve_clear_clicked (GtkButton *button, GtkWidget *dialog)
{
  gtk_clist_clear (GTK_CLIST (clist_curve));
}

void on_curve_ok_clicked (GtkButton *button, GtkWidget *dialog)
{
#ifndef NODEBUG
  g_print ("curve=%s \n", curve.curve);
  g_print ("npair=%s \n", curve.npair);
  g_print ("curvecolor=%s \n", curve.curvecolor);
#endif

  gtk_widget_destroy(GTK_WIDGET(dialog));
}

void on_curve_cancel_clicked (GtkButton *button, GtkWidget *dialog)
{
  init_curve ();
  gtk_widget_destroy(GTK_WIDGET(dialog));
}

/* Curve option dialog */
void create_dialog_curveopt (GtkWidget *widget, gpointer data)
{
  GtkWidget *dialog2;
  GtkWidget *dialog_vbox2;
  GtkWidget *frame4;
  GtkWidget *vbox4;
  GtkWidget *table4;
  GtkWidget *label_cf;
  GtkWidget *label_cn;
  GtkWidget *label_cc;
  GtkWidget *entry_cf;
  GtkObject *spinbutton_cn_adj;
  GtkWidget *spinbutton_cn;
  GtkWidget *combo_cc;
  GList *combo_cc_items = NULL;

  GtkWidget *scrolledwindow3;
  GtkWidget *label_ccf;
  GtkWidget *label_ccn;
  GtkWidget *label_ccc;

  GtkWidget *hbuttonbox3;
  GtkWidget *button_add;
  GtkWidget *button_clear;

  GtkWidget *dialog_action_area2;
  GtkWidget *hbuttonbox2;
  GtkWidget *button_curve_ok;
  GtkWidget *button_curve_cancel;

  /* Initialize */
  init_curve();

  /* Create Dialog */
  dialog2 = gtk_dialog_new ();
  gtk_window_set_title (GTK_WINDOW (dialog2), "dialog2");
  gtk_window_set_title (GTK_WINDOW (dialog2), "Curve Option");
  gtk_window_set_policy (GTK_WINDOW (dialog2), TRUE, TRUE, FALSE);

  dialog_vbox2 = GTK_DIALOG (dialog2)->vbox;
  gtk_widget_show (dialog_vbox2);

  frame4 = gtk_frame_new ("Curve Options");
  gtk_widget_show (frame4);
  gtk_box_pack_start (GTK_BOX (dialog_vbox2), frame4, TRUE, TRUE, 0);
  gtk_container_border_width (GTK_CONTAINER (frame4), 5);

  vbox4 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox4);
  gtk_container_add (GTK_CONTAINER (frame4), vbox4);
  gtk_container_border_width (GTK_CONTAINER (vbox4), 5);

  table4 = gtk_table_new (3, 2, FALSE);
  gtk_widget_show (table4);
  gtk_box_pack_start (GTK_BOX (vbox4), table4, TRUE, TRUE, 0);
  gtk_container_border_width (GTK_CONTAINER (table4), 3);

  label_cf = gtk_label_new ("File: ");
  gtk_widget_show (label_cf);
  gtk_table_attach (GTK_TABLE (table4), label_cf, 0, 1, 0, 1,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);

  label_cn = gtk_label_new ("Npair: ");
  gtk_widget_show (label_cn);
  gtk_table_attach (GTK_TABLE (table4), label_cn, 0, 1, 1, 2,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);

  label_cc = gtk_label_new ("Color");
  gtk_widget_show (label_cc);
  gtk_table_attach (GTK_TABLE (table4), label_cc, 0, 1, 2, 3,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);

  entry_cf = gtk_entry_new ();
  gtk_object_set_data (GTK_OBJECT (dialog2), "entry_cf", entry_cf);
  gtk_widget_show (entry_cf);
  gtk_table_attach (GTK_TABLE (table4), entry_cf, 1, 2, 0, 1,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);

  spinbutton_cn_adj = gtk_adjustment_new (2, 2, 50, 1, 10, 10);
  spinbutton_cn = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_cn_adj), 1, 0);
  gtk_object_set_data (GTK_OBJECT (dialog2), "spinbutton_cn", spinbutton_cn);
  gtk_widget_show (spinbutton_cn);
  gtk_table_attach (GTK_TABLE (table4), spinbutton_cn, 1, 2, 1, 2,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);

  combo_cc = gtk_combo_new ();
  gtk_object_set_data (GTK_OBJECT (dialog2), "combo_cc", combo_cc);
  gtk_widget_show (combo_cc);
  gtk_table_attach (GTK_TABLE (table4), combo_cc, 1, 2, 2, 3,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  combo_cc_items = g_list_append (combo_cc_items, "Red");
  combo_cc_items = g_list_append (combo_cc_items, "Green");
  combo_cc_items = g_list_append (combo_cc_items, "Blue");
  combo_cc_items = g_list_append (combo_cc_items, "Cyan");
  combo_cc_items = g_list_append (combo_cc_items, "Yellow");
  combo_cc_items = g_list_append (combo_cc_items, "Magenta");
  combo_cc_items = g_list_append (combo_cc_items, "Black");
  gtk_combo_set_popdown_strings (GTK_COMBO (combo_cc), combo_cc_items);
  g_list_free (combo_cc_items);

  scrolledwindow3 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_show (scrolledwindow3);
  gtk_box_pack_start (GTK_BOX (vbox4), scrolledwindow3, TRUE, TRUE, 0);
  gtk_widget_set_usize (scrolledwindow3, -2, 150);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow3), GTK_POLICY_NEVER, GTK_POLICY_ALWAYS);
   gtk_container_border_width (GTK_CONTAINER (scrolledwindow3), 3); 

  clist_curve = gtk_clist_new (3);
  gtk_object_set_data (GTK_OBJECT (dialog2), "clist_curve", clist_curve);
  gtk_widget_show (clist_curve);
  gtk_container_add (GTK_CONTAINER (scrolledwindow3), clist_curve);
  gtk_clist_set_column_width (GTK_CLIST (clist_curve), 0, 80);
  gtk_clist_set_column_width (GTK_CLIST (clist_curve), 1, 40);
  gtk_clist_set_column_width (GTK_CLIST (clist_curve), 2, 80);
  gtk_clist_set_row_height (GTK_CLIST (clist_curve), 10);
  gtk_clist_column_titles_show (GTK_CLIST (clist_curve));

  label_ccf = gtk_label_new ("File");
  gtk_widget_show (label_ccf);
  gtk_clist_set_column_widget (GTK_CLIST (clist_curve), 0, label_ccf);

  label_ccn = gtk_label_new ("Npair");
  gtk_widget_show (label_ccn);
  gtk_clist_set_column_widget (GTK_CLIST (clist_curve), 1, label_ccn);

  label_ccc = gtk_label_new ("Color");
  gtk_widget_show (label_ccc);
  gtk_clist_set_column_widget (GTK_CLIST (clist_curve), 2, label_ccc);

  hbuttonbox3 = gtk_hbutton_box_new ();
  gtk_widget_show (hbuttonbox3);
  gtk_box_pack_start (GTK_BOX (vbox4), hbuttonbox3, TRUE, TRUE, 0);
   gtk_container_border_width (GTK_CONTAINER ( hbuttonbox3), 3); 

  button_add = gtk_button_new_with_label ("Add");
  gtk_widget_show (button_add);
  gtk_container_add (GTK_CONTAINER (hbuttonbox3), button_add);
  gtk_signal_connect (GTK_OBJECT (button_add), "clicked",
                      GTK_SIGNAL_FUNC (on_curve_add_clicked),
                      dialog2);

  button_clear = gtk_button_new_with_label ("Clear");
  gtk_widget_show (button_clear);
  gtk_container_add (GTK_CONTAINER (hbuttonbox3), button_clear);
  gtk_signal_connect (GTK_OBJECT (button_clear), "clicked",
                      GTK_SIGNAL_FUNC (on_curve_clear_clicked),
                      dialog2);

  dialog_action_area2 = GTK_DIALOG (dialog2)->action_area;
  gtk_widget_show (dialog_action_area2);
  gtk_container_border_width (GTK_CONTAINER (dialog_action_area2), 10);

  hbuttonbox2 = gtk_hbutton_box_new ();
  gtk_widget_show (hbuttonbox2);
  gtk_box_pack_start (GTK_BOX (dialog_action_area2), hbuttonbox2, TRUE, TRUE, 0);

  button_curve_ok = gtk_button_new_with_label ("OK");
  gtk_widget_show (button_curve_ok);
  gtk_container_add (GTK_CONTAINER (hbuttonbox2), button_curve_ok);
  gtk_signal_connect (GTK_OBJECT (button_curve_ok), "clicked",
                      GTK_SIGNAL_FUNC (on_curve_ok_clicked),
                      dialog2);

  button_curve_cancel = gtk_button_new_with_label ("Cancel");
  gtk_widget_show (button_curve_cancel);
  gtk_container_add (GTK_CONTAINER (hbuttonbox2), button_curve_cancel);
  gtk_signal_connect (GTK_OBJECT (button_curve_cancel), "clicked",
                      GTK_SIGNAL_FUNC (on_curve_cancel_clicked),
                      dialog2);

  gtk_widget_show (dialog2);

  gtk_grab_add(dialog2);
  gtk_main ();
  gtk_grab_remove(dialog2);

  return;
}

