/*  suxviewer
 *  Copyright (C) 1999, Watanabe Toshiki
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
*/

#include <stdio.h>
#include <gtk/gtk.h>
#include "suxviewer.h"
#include "option.h"
#include "config.h"

/* Make a shell script and execute it */

/* suxwigb */
int exec_view_wiggle (GtkWidget *button, gpointer data)
{
  FILE *fp;
  char *shell_file = "sv.sh";

  if(filename == NULL) {
    g_print ("Oops, you haven't selected any files to be plotted.\n");
    return 0;
  }

  if((fp = fopen("sv.sh", "w")) != NULL) {
    fprintf (fp, "#!/bin/sh\n");
    fprintf (fp, "# sv.sh: generated by suxviewer \n\n");
    fprintf (fp, "suxwigb \\\n");
    
    /* Option */
    if(option.yes == 1) {
      
      fprintf (fp, "style=%s ", option.style);
      fprintf (fp, "wt=%s ", option.wt);
      fprintf (fp, "va=%s ", option.va);
      fprintf (fp, "interp=%s ", option.interp);
      fprintf (fp, "key=%s \\\n", option.key);
      
      fprintf (fp, "bias=%s ", option.bias);
      fprintf (fp, "perc=%s ", option.perc);
      if(strcmp(option.clip, "(perc)") != 0) fprintf (fp, "clip=%s \\\n", option.clip);
      fprintf (fp, "xcur=%s ", option.xcur);
      fprintf (fp, "wigclip=%s \\\n", option.wigclip);
      
      fprintf (fp, "mpicks=\"%s\" \\\n", option.mpicks);
      
      fprintf (fp, "title=\"%s\" \\\n", option.title);
      fprintf (fp, "label1=\"%s\" ", option.label1);
      if(strcmp(option.min1, "(min)") != 0 ) fprintf (fp, "x1beg=%s \\\n", option.min1);
      if(strcmp(option.max1, "(max)") != 0 ) fprintf (fp, "x1end=%s \\\n", option.max1);
      if(strcmp(option.d1num, "(auto)") != 0 ) fprintf (fp, "d1num=%s \\\n", option.d1num);
      fprintf (fp, "n1tic=%s ", option.tic1);
      fprintf (fp, "grid1=%s \\\n", option.grid1);
      fprintf (fp, "label2=\"%s\" ", option.label2);
      if(strcmp(option.min2, "(min)") != 0 ) fprintf (fp, "x2beg=%s \\\n", option.min2);
      if(strcmp(option.max2, "(max)") != 0 ) fprintf (fp, "x2end=%s \\\n", option.max2);
      if(strcmp(option.d2num, "(auto)") != 0 ) fprintf (fp, "d2num=%s \\\n", option.d2num);
      fprintf (fp, "n2tic=%s ", option.tic2);
      fprintf (fp, "grid2=%s \\\n", option.grid2);
      
      if (*option.add) fprintf (fp, "%s \\\n", option.add);
    }
    
    /* Curve */
    if(curve.ncurve != 0) {
      fprintf (fp, "curve=%s ", curve.curve);
      fprintf (fp, "npair=%s ", curve.npair);
      fprintf (fp, "curvecolor= %s \\\n", curve.curvecolor);
    }

    fprintf (fp, "< %s & \n", filename);
    fprintf (fp, "exit \n");
    fclose(fp);

    system("/bin/sh sv.sh"); 

#ifdef NODEBUG
    system("/bin/rm sv.sh"); 
#endif

    return 1;
  }
  return 0;
}

/* suximage */
int exec_view_image (GtkWidget *button, gpointer data)
{
  FILE *fp;
  char *shell_file = "sv.sh";

  if(filename == NULL) {
    g_print ("Oops, you haven't selected any files to be plotted.\n");
    return 0;
  }

  if((fp = fopen("sv.sh", "w")) != NULL) {
    fprintf (fp, "#!/bin/sh \n");
    fprintf (fp, "# sv.sh: generated by suxviewer \n\n");
    fprintf (fp, "suximage \\\n");

    /* Option */
    if(option.yes == 1) {

      fprintf (fp, "style=%s ", option.style);
      fprintf (fp, "key=%s \\\n", option.key);
      
      fprintf (fp, "perc=%s ", option.perc);
      if(strcmp(option.clip, "(perc)") != 0) fprintf (fp, "clip=%s \\\n", option.clip);
      
      fprintf (fp, "mpicks=\"%s\" \\\n", option.mpicks);
      
      fprintf (fp, "title=\"%s\" \\\n", option.title);
      fprintf (fp, "label1=\"%s\" ", option.label1);
      if(strcmp(option.min1, "(min)") != 0 ) fprintf (fp, "x1beg=%s \\\n", option.min1);
      if(strcmp(option.max1, "(max)") != 0 ) fprintf (fp, "x1end=%s \\\n", option.max1);
      if(strcmp(option.d1num, "(auto)") != 0 ) fprintf (fp, "d1num=%s \\\n", option.d1num);
      fprintf (fp, "n1tic=%s ", option.tic1);
      fprintf (fp, "grid1=%s \\\n", option.grid1);
      fprintf (fp, "label2=\"%s\" ", option.label2);
      if(strcmp(option.min2, "(min)") != 0 ) fprintf (fp, "x2beg=%s \\\n", option.min2);
      if(strcmp(option.max2, "(max)") != 0 ) fprintf (fp, "x2end=%s \\\n", option.max2);
      if(strcmp(option.d2num, "(auto)") != 0 ) fprintf (fp, "d2num=%s \\\n", option.d2num);
      fprintf (fp, "n2tic=%s ", option.tic2);
      fprintf (fp, "grid2=%s \\\n", option.grid2);
      
      if (*option.add) fprintf (fp, "%s \\\n", option.add);
    }

    /* Image option */
    if(image.yes == 1) {
      if(strcmp(image.bperc, "(perc)") != 0 ) fprintf (fp, "bperc=%s ", image.bperc);
      if(strcmp(image.wperc, "(100-perc)") != 0 ) fprintf (fp, "wperc=%s ", image.wperc);
      if(strcmp(image.bclip, "(clip)") != 0 ) fprintf (fp, "bclip=%s ", image.bclip);
      if(strcmp(image.wclip, "(-clip)") != 0 ) fprintf (fp, "wclip=%s ", image.wclip);
      fprintf (fp, "blank=%s ", image.blank);
      fprintf (fp, "cmap=%s \\\n", image.cmap);
    }

    /* Legend */
    if(legend.yes == 1) {
      fprintf (fp, "legend=%s ", legend.legend);
      if(strcmp(legend.units, "(none)") != 0 ) fprintf (fp, "units=%s ", legend.units);
      fprintf (fp, "xbox=%s ", legend.xbox);
      fprintf (fp, "ybox=%s ", legend.ybox);
      fprintf (fp, "lwidth=%s ", legend.lwidth);
      fprintf (fp, "lheight=%s ", legend.lheight);
      fprintf (fp, "lx=%s ", legend.lx);
      fprintf (fp, "ly=%s \\\n", legend.ly);
    }

    /* Curve */
    if(curve.ncurve != 0) {
      fprintf (fp, "curve=%s ", curve.curve);
      fprintf (fp, "npair=%s ", curve.npair);
      fprintf (fp, "curvecolor= %s \\\n", curve.curvecolor);
    }

    fprintf (fp, "< %s & \n", filename);
    fprintf (fp, "exit \n");
    fclose(fp);

    system("/bin/sh sv.sh"); 
#ifdef NODEBUG
    system("/bin/rm sv.sh"); 
#endif

    return 1;
  }
  return 0;
}

